==> xlniuxdata-vipgame-1.0.65-20160713.022127-12-sources.jar: com/xunlei/niux/data/vipgame/vo/mobileguild/MobileGuildGame.java <==
package com.xunlei.niux.data.vipgame.vo.mobileguild;

import com.ferret.common.dao.annotation.Table;

/**
 * @author Administrator
 *
 */
@Table(tableName="mobileguildgame",pkFieldName="seqId",pkFieldAssign=false)
public class MobileGuildGame {
	private Long seqId;
	private String gameId;
	private String outputTime;

	private String  inputBy;
	private String  inputTime;
	private String	editTime;
	private String	editBy;
	private Boolean isDel;
	private String firstSpell;
	private Long apkId;
	private String appVersion;

	public Long getSeqId() {
		return seqId;
	}

	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}

	public String getGameId() {
		return gameId;
	}

	public void setGameId(String gameId) {
		this.gameId = gameId;
	}

	public String getOutputTime() {
		return outputTime;
	}

	public void setOutputTime(String outputTime) {
		this.outputTime = outputTime;
	}

	public String getInputBy() {
		return inputBy;
	}

	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}

	public String getInputTime() {
		return inputTime;
	}

	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}

	public String getEditTime() {
		return editTime;
	}

	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}

	public String getEditBy() {
		return editBy;
	}

	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}

	public Boolean getIsDel() {
		return this.isDel;
	}

	public void setIsDel(Boolean isDel) {
		this.isDel = isDel;
	}

	public String getFirstSpell() {
		return firstSpell;
	}

	public void setFirstSpell(String firstSpell) {
		this.firstSpell = firstSpell;
	}

	public Long getApkId() {
		return apkId;
	}

	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}

	public String getAppVersion() {
		return appVersion;
	}

	public void setAppVersion(String appVersion) {
		this.appVersion = appVersion;
	}
}

==> xlniuxdata-vipgame-1.0.119-sources.jar: com/xunlei/niux/data/vipgame/vo/mobileguild/MobileGuildGame.java <==
package com.xunlei.niux.data.vipgame.vo.mobileguild;

import com.ferret.common.dao.annotation.Table;

/**
 * @author Administrator
 *
 */
@Table(tableName="mobileguildgame",pkFieldName="seqId",pkFieldAssign=false)
public class MobileGuildGame {
	private Long seqId;
	private String gameId;
	private String outputTime;

	private String  inputBy;
	private String  inputTime;
	private String	editTime;
	private String	editBy;
	private Boolean isDel;
	private String firstSpell;
	private Long apkId;
	private String appVersion;
	private Integer discount;

	public Long getSeqId() {
		return seqId;
	}

	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}

	public String getGameId() {
		return gameId;
	}

	public void setGameId(String gameId) {
		this.gameId = gameId;
	}

	public String getOutputTime() {
		return outputTime;
	}

	public void setOutputTime(String outputTime) {
		this.outputTime = outputTime;
	}

	public String getInputBy() {
		return inputBy;
	}

	public void setInputBy(String inputBy) {
		this.inputBy = inputBy;
	}

	public String getInputTime() {
		return inputTime;
	}

	public void setInputTime(String inputTime) {
		this.inputTime = inputTime;
	}

	public String getEditTime() {
		return editTime;
	}

	public void setEditTime(String editTime) {
		this.editTime = editTime;
	}

	public String getEditBy() {
		return editBy;
	}

	public void setEditBy(String editBy) {
		this.editBy = editBy;
	}

	public Boolean getIsDel() {
		return this.isDel;
	}

	public void setIsDel(Boolean isDel) {
		this.isDel = isDel;
	}

	public String getFirstSpell() {
		return firstSpell;
	}

	public void setFirstSpell(String firstSpell) {
		this.firstSpell = firstSpell;
	}

	public Long getApkId() {
		return apkId;
	}

	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}

	public String getAppVersion() {
		return appVersion;
	}

	public void setAppVersion(String appVersion) {
		this.appVersion = appVersion;
	}

	public Integer getDiscount() {
		return discount;
	}

	public void setDiscount(Integer discount) {
		this.discount = discount;
	}
}
